# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['rummy',
 'rummy.constants',
 'rummy.controller',
 'rummy.deck',
 'rummy.exception',
 'rummy.game',
 'rummy.player',
 'rummy.ui',
 'rummy.view']

package_data = \
{'': ['*'], 'rummy': ['templates/*']}

install_requires = \
['Pygments==2.2.0',
 'ansi-colours==0.2.6',
 'atomicwrites==1.2.1',
 'attrs==18.2.0',
 'bleach==3.0.2',
 'certifi==2018.10.15',
 'chardet==3.0.4',
 'codecov==2.0.15',
 'colorama==0.4.0',
 'coverage==4.5.1',
 'docutils==0.14',
 'idna==2.7',
 'more-itertools==4.3.0',
 'pathlib2==2.3.2',
 'pkginfo==1.4.2',
 'pluggy==0.8.0',
 'py==1.7.0',
 'pytest-cov==2.6.0',
 'pytest-mock==1.10.0',
 'pytest==3.10.0',
 'readme-renderer==24.0',
 'requests-toolbelt==0.8.0',
 'requests==2.20.1',
 'six==1.11.0',
 'text-template==0.1.4',
 'tqdm==4.28.1',
 'twine==1.12.1',
 'urllib3==1.24.1',
 'webencodings==0.5.1']

setup_kwargs = {
    'name': 'rummy',
    'version': '2.0.0',
    'description': 'Console Rummy game',
    'long_description': None,
    'author': 'Sarcoma',
    'author_email': 'sarcoma@live.co.uk',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.4,<4.0',
}


setup(**setup_kwargs)
